@@ -1,7 +1,10 @@
+#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  SPDX-License-Identifier: Apache-2.0
+
 import luigi
 
-from servicecatalog_puppet.workflow import tasks
 from servicecatalog_puppet import constants
+from servicecatalog_puppet.workflow import tasks
 from servicecatalog_puppet.workflow.manifest import manifest_mixin
 
 
@@ -23,3 +26,7 @@ class SpokeLocalPortfolioBaseTask(tasks.PuppetTask, manifest_mixin.ManifestMixen
     @property
     def item_name(self):
         return self.spoke_local_portfolio_name
+
+    @property
+    def item_identifier(self):
+        return "spoke_local_portfolio_name"
